function makePhone(game)
{
    var phone = game.add.graphics(30,30);
    game.data.phone = phone;
    phone.beginFill(0xfdfdff);
    phone.drawRoundedRect(0,0,350,700,30);
    
    //bar thing
    phone.beginFill(0x111111);
    phone.drawRoundedRect(350/2-25,20,50,10,4);
    
    //camera
    phone.drawCircle(350/2-40-30,54,16);

    phone.screenMask = phone.addChild(game.add.graphics());
    phone.screenMask.beginFill(0xffffff);
    phone.screenMask.drawRect(20,105,310,470);
    
    //screen bg
    phone.drawRoundedRect(15,100,320,480,10);

    phone.screen = phone.addChild(game.add.button(12,98,'screen'));
    phone.screen.animations.add('normal',[2,3,4,3],1,true);
    phone.screen.visible = false;
    
    phone.startup = phone.screen.addChild(game.add.sprite(0,0,'nemesis'));
    phone.startup.visible = false;
    
    phone.chatDialogue = phone.screen.addChild(game.add.group());
    phone.chatDialogue.mask = phone.screenMask;
    
    phone.dragging = false;
    phone.allowDragging = false;
    phone.startDrag = function() {
        if (!this.allowDragging) { return; }
        this.dragging = true;
        this.dragStart = this.game.input.activePointer.x;
    }
    
    phone.endDrag = function() {
        if (!this.allowDragging) { return; }
        this.dragging = false;
    }
    
    phone.screen.onInputDown.add(phone.startDrag, phone);
    phone.screen.onInputUp.add(phone.endDrag, phone);
    
    //speaker
    phone.beginFill(0x999999);
    phone.drawRoundedRect(350/2-40,50,80,8,3);
    
    //home circle
    phone.endFill();
    phone.lineStyle(1,0x999999,1);
    phone.drawCircle(350/2,700-55,60);
    
    //phone border
    phone.lineStyle(3,0x333333,0.3);
    phone.drawRoundedRect(4,3,342,694,28);
    
    //home icon
    game.add.tween(phone).to( { x: 630 }, 1500, Phaser.Easing.Elastic.Out, true );
    
    // function bindings
    phone.turnOn = turnOn;
    phone.playTutorial = playTutorial;
    phone.getNewOpponent = getNewOpponent;
    phone.doNextOpponent = doNextOpponent;
    phone.showChat = showChat;
    phone.showMonsterChat = showMonsterChat;
    phone.showPlayerChat = showPlayerChat;
    phone.playMatchAnimation = playMatchAnimation;
    phone.updateChatDialogue = updateChatDialogue;
    phone.clearChat = clearChat;
    
    phone.update = function() {
        if ((this.opponent === undefined) || (!this.allowDragging)) { return; }
        if (this.dragging) {
            this.opponent.pic.setPosition(0.5*(this.game.input.activePointer.x - this.dragStart));
        } else {
            this.opponent.pic.setPosition((this.opponent.pic.shiftX)*0.95);
        }
        if (Math.abs(this.opponent.pic.shiftX) > 0.5) {
            this.opponent.accepted = this.opponent.pic.shiftX > 0;
            this.doNextOpponent();
        }
    }
    
    return phone;
}

function turnOn()
{
    this.screen.visible = true;
    this.screen.animations.play('normal');
    this.startup.visible = true;
}

function playTutorial(triggerFunction)
{
    this.game.time.events.add(5000,triggerFunction,this.game.state.getCurrentState());
}

function getNewOpponent()
{
    this.clearChat();
    if (this.opponent != undefined) { 
        this.opponent.destroy();
    }
    
    this.opponent = this.screen.addChild(makeNewOpponentData(this.game));
    this.opponent.pic = this.opponent.addChild(makeSwipeable(this.game,this.opponent.color));
    this.opponent.pic.mask = this.screenMask;
    
    this.opponentName = lineHandler(this.game,this.opponent,this.opponent.name,'fabrica',60);
    this.opponentName.anchor.setTo(0.5);
    this.opponentName.x = 150;
    this.opponentName.fontSize = 30;
    
    this.flavorText = lineHandler(this.game,this.opponent,this.opponent.status,'fabrica',375);
    this.flavorText.x = 30;
    
    this.allowDragging = true;
}

function doNextOpponent()
{
    this.allowDragging = false;
    this.dragging = false;
    this.game.add.tween(this.opponent).to({alpha: 0.0}, 1000, Phaser.Easing.Linear.None, true);
    this.game.add.tween(this.opponentName).to({alpha: 0.0}, 1000, Phaser.Easing.Linear.None, true);
    this.game.add.tween(this.flavorText).to({alpha: 0.0}, 1000, Phaser.Easing.Linear.None, true);
    if (this.opponent.accepted && Math.random() < 0.9)
    {
        this.playMatchAnimation();
        this.game.state.getCurrentState().doMatch()
    }
    else
    {
        this.game.time.events.add(100,this.getNewOpponent,this);
    }
}

function playMatchAnimation()
{
    if (this.chatOpts != undefined) { this.chatOpts.destroy(true,true); }
    this.chatOpts = this.addChild(makeChatOptions(this.game,this.opponent));
}

function showChat(question)
{
    var p = getQuestionPhrasing(question);
    this.showPlayerChat(p);
    if (question == 'meet up?') {
        this.showMonsterChat(getRandomFromList(['ayy!! yeh lol', 'omg yess!!!! <3 <3 <3', 'sure im gonna rock u so hard lolol', 'heck yes ;)']));
        this.game.state.getCurrentState().doBattle();
    } else if (question == 'see ya') {
        this.game.state.getCurrentState().runTinder();
        this.game.state.getCurrentState().phone.getNewOpponent();
    } else {
        var response = this.opponent.getResponse(question);
        this.showMonsterChat(response);
    }
    
}

function showMonsterChat(line)
{
    var y = 0;
    var i = 0;
    while (i < this.chatDialogue.children.length)
    {
        y += 10 + this.chatDialogue.children[i].h;
        i++;
    }
    var txt = this.chatDialogue.addChild(this.game.add.sprite());
    txt.gfx = txt.addChild(this.game.add.graphics());
    txt.text = lineHandler(this.game,txt,line,'fabrica',0);
    txt.text.align = 'left';
    txt.text.fontSize = 20;
    txt.gfx.beginFill(0x555555);
    txt.gfx.drawRoundedRect(-4,-4,txt.text.width+8,txt.text.height+8,3);
    txt.gfx.alpha = 0.8;
    txt.y = y;
    txt.x = 16;
    txt.h = txt.text.height + 8;
    this.updateChatDialogue();
}

function showPlayerChat(line)
{
    var y = 0;
    var i = 0;
    while (i < this.chatDialogue.children.length)
    {
        y += 10 + this.chatDialogue.children[i].h;
        i++;
    }
    var txt = this.chatDialogue.addChild(this.game.add.sprite());
    txt.gfx = txt.addChild(this.game.add.graphics());
    txt.text = lineHandler(this.game,txt,line,'fabrica',0);
    txt.text.align = 'right';
    txt.text.fontSize = 20;
    txt.gfx.beginFill(0x0000FF);
    txt.gfx.drawRoundedRect(-4,-4,txt.text.width+8,txt.text.height+8,3);
    txt.gfx.alpha = 0.5;
    txt.y = y;
    txt.x = 320 - txt.text.width - 8;
    txt.h = txt.text.height + 8;
    this.updateChatDialogue();
}

function updateChatDialogue()
{
    this.chatDialogue.y = 450 - this.chatDialogue.getLocalBounds().height;
}

function clearChat()
{
    this.chatDialogue.destroy(true,true);
}